@@ -15,6 +15,7 @@ from dpgen.auto_test.calculator import make_calculator
 from dpgen.dispatcher.Dispatcher import make_dispatcher
 from dpgen.dispatcher.Dispatcher import make_submission
 from dpgen.remote.decide_machine import convert_mdata
+from dpgen.auto_test.lib.utils import create_path
 lammps_task_type = ['deepmd', 'meam', 'eam_fs', 'eam_alloy']
 
 
@@ -73,10 +74,7 @@ def make_property(confs,
             path_to_equi = os.path.join(ii, 'relaxation', 'relax_task')
             path_to_work = os.path.join(ii, property_type + '_' + suffix)
 
-            if os.path.exists(path_to_work):
-                dlog.warning('%s already exists' % path_to_work)
-            else:
-                os.makedirs(path_to_work)
+            create_path(path_to_work)
 
             prop = make_property_instance(jj)
             task_list = prop.make_confs(path_to_work, path_to_equi, do_refine)
@@ -112,6 +110,7 @@ def run_property(confs,
     conf_dirs.sort()
     task_list = []
     work_path_list = []
+    multiple_ret = []
     for ii in conf_dirs:
         sepline(ch=ii, screen=True)
         for jj in property_list:
@@ -159,7 +158,7 @@ def run_property(confs,
             all_task = tmp_task_list
             run_tasks = util.collect_task(all_task, inter_type)
             if len(run_tasks) == 0:
-                return
+                continue
             else:
                 ret = pool.apply_async(worker, (work_path,
                                                 all_task,
@@ -169,23 +168,13 @@ def run_property(confs,
                                                 mdata,
                                                 inter_type,
                                                 ))
-            # run_tasks = [os.path.basename(ii) for ii in all_task]
-            # machine, resources, command, group_size = util.get_machine_info(mdata, inter_type)
-            # disp = make_dispatcher(machine, resources, work_path, run_tasks, group_size)
-            # disp.run_jobs(resources,
-            #               command,
-            #               work_path,
-            #               run_tasks,
-            #               group_size,
-            #               forward_common_files,
-            #               forward_files,
-            #               backward_files,
-            #               outlog='outlog',
-            #               errlog='errlog')
+                multiple_ret.append(ret)
     pool.close()
     pool.join()
-    if ret.successful():
-        print('finished')
+    for ii in range(len(multiple_ret)):
+        if not multiple_ret[ii].successful():
+            raise RuntimeError("Job %d is not successful!" % ii)
+    print('%d jobs are finished' % len(multiple_ret))
 
 
 def worker(work_path,
@@ -215,7 +204,7 @@ def worker(work_path,
     elif LooseVersion(api_version) >= LooseVersion('1.0'):
         submission = make_submission(
                 mdata_machine=machine,
-                mdata_resource=resources,
+                mdata_resources=resources,
                 commands=[command],
                 work_path=work_path,
                 run_tasks=run_tasks,
