@@ -80,9 +80,9 @@ def out_dir_name(jdata) :
     from_poscar = False
     if 'from_poscar' in jdata :
         from_poscar = jdata['from_poscar']
-        from_poscar_path = jdata['from_poscar_path']
 
     if from_poscar:
+        from_poscar_path = jdata['from_poscar_path']
         poscar_name = os.path.basename(from_poscar_path)
         cell_str = "%02d" % (super_cell[0])
         for ii in range(1,len(super_cell)) :
@@ -464,7 +464,7 @@ def make_vasp_md(jdata, mdata) :
 
     for ii in sys_ps :
         for jj in scale :
-            for kk in range(pert_numb) :
+            for kk in range(pert_numb+1) :
                 path_work = path_md
                 path_work = os.path.join(path_work, ii)
                 path_work = os.path.join(path_work, "scale-%.3f" % jj)
@@ -534,6 +534,8 @@ def coll_vasp_md(jdata) :
                     #dlog.info("md_nstep", md_nstep)
                     if nforce == md_nstep :
                         valid_outcars.append(outcar)
+                    elif md_nstep == 0 and nforce == 1 :
+                        valid_outcars.append(outcar)
                     else:
                         dlog.info("WARNING : in directory %s nforce in OUTCAR is not equal to settings in INCAR"%(os.getcwd()))
         arg_cvt = " "
@@ -767,13 +769,14 @@ def gen_init_bulk(args) :
             dlog.info("Current stage is 1, relax")
             create_path(out_dir)
             shutil.copy2(args.PARAM, os.path.join(out_dir, 'param.json'))
+            skip_relax = jdata['skip_relax']
             if from_poscar :
                 make_super_cell_poscar(jdata)
             else :
                 make_unit_cell(jdata)
                 make_super_cell(jdata)
                 place_element(jdata)
-            if args.MACHINE is not None:
+            if args.MACHINE is not None and not skip_relax:
                make_vasp_relax(jdata, mdata)
                run_vasp_relax(jdata, mdata)
             else:
